@@ -191,7 +191,7 @@ class Process {
     for (int i = fds_->size() - 1; i >= 0; i--) {
       FileFD* file_fd = get_fd(i);
       if (file_fd) {
-        handle_close(file_fd);
+        handle_close(file_fd, i);
       }
     }
   }
@@ -248,7 +248,7 @@ class Process {
    * @param ar_len length of ar_name
    * @param flags flags of open()
    * @param mode mode (create permissions) of open()
-   * @param fd the return value, or -1 if file was dlopen()ed successfully
+   * @param fd the return value, or -1 if file was open()ed successfully
    * @param error error code of open()
    * @param fd_conn fd to send ACK on when needed
    * @param ack_num ACK number to send or 0 if sending ACK is not needed
@@ -277,16 +277,14 @@ class Process {
 
   /**
    * Handle dlopen() in the monitored process
-   * @param absolute_filename absolute file name
-   * @param absolute_filename_len length of absolute_filename
+   * @param absolute_filenames absolute file names of loaded shared libraries
    * @param looked_up_filename file name passed to dlopen()
    * @param looked_up_filename_len length of looked_up_filename
    * @param error true when dlopen failed to open the file
    * @param fd_conn fd to send ACK on when needed
    * @param ack_num ACK number to send or 0 if sending ACK is not needed
    */
-  int handle_dlopen(const char * const absolute_filename,
-                    const size_t absolute_filename_len,
+  int handle_dlopen(const std::vector<std::string>& absolute_filenames,
                     const char * const looked_up_filename,
                     const size_t looked_up_filename_len,
                     const bool error, int fd_conn, int ack_num);
@@ -300,8 +298,9 @@ class Process {
   /**
    * Handle file closure in the monitored process
    * @param file_fd FileFD* to close
+   * @param fd file descriptor to close
    */
-  void handle_close(FileFD * file_fd);
+  void handle_close(FileFD * file_fd, const int fd);
 
   /**
    * Handle file closure in the monitored process when we don't know
@@ -325,6 +324,12 @@ class Process {
   int handle_close_range(const unsigned int first, const unsigned int last,
                          const int flags, const int error = 0);
 
+  /**
+   * Handle scandirat() in the monitored process.
+   */
+  int handle_scandirat(const int dirfd, const char * const ar_name, const size_t ar_name_len,
+                       const int error);
+
   /**
    * Handle truncate() in the monitored process..
    */
@@ -365,6 +370,13 @@ class Process {
   int handle_statfs(const char * const name, const size_t name_len,
                     const int error = 0);
 
+  /**
+   * Handle mktemp in the monitored process
+   * @param name absolute file name
+   * @param name_len length of name
+   */
+  int handle_mktemp(const char * const name, const size_t name_len);
+
   /**
    * Handle access, e[uid]access, faccessat in the monitored process
    */
@@ -383,6 +395,24 @@ class Process {
   int handle_fchmodat(const int fd, const char * const name, const size_t name_len,
                       const mode_t mode, const int flags, const int error = 0);
 
+  /**
+   * Handle shm_open() in the monitored process
+   * @param name of the shared memory object
+   * @param oflag oflag of shm_open()
+   * @param mode mode (create permissions) of shm_open()
+   * @param fd the return value, or -1 if shared memory object was shm_open()-ed successfully
+   * @param error error code of shm_open()
+   */
+  int handle_shm_open(const char * const name, const int oflag,
+                      const mode_t mode, const int fd, const int error);
+
+#ifdef __APPLE__
+  /**
+   * Handle kqueue() in the monitored process
+   */
+  int handle_kqueue(const int fd, const int error);
+#endif
+
 #ifdef __linux__
   /**
    * Handle memfd_create in the monitored process
@@ -460,6 +490,12 @@ class Process {
   void handle_socketpair(const int domain, const int type, const int protocol,
                          const int fd0, const int fd1, const int error);
 
+  /**
+   * Handle connect() in the monitored process
+   */
+  void handle_connect(const int sockfd, const char * const address, const size_t address_len,
+                      const int error);
+
   /**
    * Handle dup(), dup2() or dup3() in the monitored process
    * @param oldfd old fd
@@ -606,7 +642,7 @@ class Process {
 
  private:
   Process *parent_;
-  process_state state_ :2;
+  process_state state_ :2 = FB_PROC_RUNNING;
   int fb_pid_;       ///< internal Firebuild id for the process
   int pid_;          ///< UNIX pid
   int ppid_;         ///< UNIX ppid
@@ -639,7 +675,7 @@ class Process {
   bool posix_spawn_pending_ {false};
   /** Debugging is suppressed for this process. */
   bool debug_suppressed_;
-  ExecedProcess * exec_child_;
+  ExecedProcess * exec_child_ = nullptr;
   const FileName* get_fd_filename(int fd) const;
   bool any_child_not_finalized();
   DISALLOW_COPY_AND_ASSIGN(Process);
