@@ -22,7 +22,6 @@
 
 #include <algorithm>
 #include <cinttypes>
-#include <iostream>
 #include <limits>
 #include <set>
 #include <sstream>
@@ -140,7 +139,7 @@ static void export2js(const ExecedProcess* proc, const unsigned int level,
 
   fprintf(stream, "%s libs: [", indent);
   for (auto& lib : proc->libs()) {
-    fprintf(stream, "\"%s\",", lib->c_str());
+    fprintf(stream, "files[%d],", used_files_index_map[lib]);
   }
   fprintf(stream, "],\n");
 
@@ -264,6 +263,9 @@ static void collect_used_files_and_envs(const Process &p,
         used_files->insert(pair.first);
       }
     }
+    for (const FileName* lib : exec_child->libs()) {
+      used_files->insert(lib);
+    }
     envs->insert(&exec_child->env_vars());
     collect_used_files_and_envs(*exec_child, used_files, envs);
   }
@@ -563,8 +565,7 @@ void Report::write(const std::string &html_filename, const std::string &datadir)
   }
   fclose(src_file);
   fclose(dst_file);
-  std::cout << "FIREBUILD: Generated report: " + html_filename << std::endl;
+  fb_info("Generated report: " + html_filename);
 }
 
 }  /* namespace firebuild */
-
