@@ -18,6 +18,7 @@
 
 #define _GNU_SOURCE
 #include <dirent.h>
+#include <dlfcn.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <signal.h>
@@ -140,6 +141,22 @@ int main() {
   }
   closedir(d);
 
+#ifdef __APPLE__
+  d = __opendir2("./", 0);
+  if (d == NULL) {
+    perror("__opendir2" LOC);
+    exit(1);
+  }
+  closedir(d);
+#endif
+
+  struct dirent **namelist;
+  if (scandir("./", &namelist, NULL, NULL) == -1) {
+    perror("scandir" LOC);
+    exit(1);
+  }
+  free(namelist);
+
   if (mkdir("test_directory", 0700) == -1) {
     perror("mkdir" LOC);
     exit(1);
@@ -155,14 +172,21 @@ int main() {
   close(fd);
 #endif
 
-  char tmp_file[] = "tmpprefixXXXXXX";
-  fd = mkstemp(tmp_file);
+  char tmp_file1[] = "tmpprefixXXXXXX";
+  mktemp(tmp_file1);
+  if (tmp_file1[0] == '\0') {
+    perror("mktemp" LOC);
+    exit(1);
+  }
+
+  char tmp_file2[] = "tmpprefixXXXXXX";
+  fd = mkstemp(tmp_file2);
   if (fd == -1) {
     perror("mkstemp" LOC);
     exit(1);
   }
   close(fd);
-  unlink(tmp_file);
+  unlink(tmp_file2);
 
   char tmp_dir[] = "./prefixXXXXXX";
   char *mkdtemp_ret = mkdtemp(tmp_dir);
@@ -253,6 +277,20 @@ int main() {
     exit(1);
   }
 
+#ifdef __APPLE__
+#define SO_EXTENSION "dylib"
+#else
+#define SO_EXTENSION "so"
+#endif
+  if (dlopen("./libtest_dlopen_lib." SO_EXTENSION, RTLD_NOW) == NULL) {
+    perror("dlopen" LOC);
+    exit(1);
+  }
+  if (dlopen("./libtest_dlopen_notexists_lib." SO_EXTENSION, RTLD_NOW) != NULL) {
+    perror("dlopen" LOC);
+    exit(1);
+  }
+
   /* Run part 2. */
   fd = open("test_nonempty_2.txt", O_WRONLY);
   lseek(fd, -2, SEEK_END);
